@@ -1,11 +1,10 @@
+#include "pathexec.h"
 #include "strerr.h"
 
-void main(argc,argv)
-int argc;
-char **argv;
+main(int argc,char **argv,char **envp)
 {
   if (argc < 3)
     strerr_die1x(100,"argv0: usage: argv0 realname program [ arg ... ]");
-  execvp(argv[1],argv + 2);
+  pathexec_run(argv[1],argv + 2,envp);
   strerr_die4sys(111,"argv0: fatal: ","unable to run ",argv[1],": ");
 }
