@@ -1,8 +1,7 @@
-#include "substdio.h"
-#include "subfd.h"
+#include "buffer.h"
 #include "exit.h"
 
-void main()
+main()
 {
   register int n;
   register char *x;
@@ -10,28 +9,29 @@ void main()
   register int flagcr = 0;
 
   for (;;) {
-    n = substdio_feed(subfdin);
+    n = buffer_feed(buffer_0);
     if (n < 0) _exit(111);
     if (!n) {
-      if (flagcr) substdio_BPUTC(subfdout,"\r"[0]);
+      if (flagcr) buffer_PUTC(buffer_1,"\r"[0]);
+      buffer_flush(buffer_1);
       _exit(0);
     }
-    x = substdio_PEEK(subfdin);
-    substdio_SEEK(subfdin,n);
+    x = buffer_PEEK(buffer_0);
+    buffer_SEEK(buffer_0,n);
 
     while (n > 0) {
       ch = *x++; --n;
       if (!flagcr) {
         if (ch == '\r') { flagcr = 1; continue; }
-	substdio_BPUTC(subfdout,ch);
+	buffer_PUTC(buffer_1,ch);
 	continue;
       }
       if (ch != '\n') {
-        substdio_BPUTC(subfdout,"\r"[0]);
+        buffer_PUTC(buffer_1,"\r"[0]);
         if (ch == '\r') continue;
       }
       flagcr = 0;
-      substdio_BPUTC(subfdout,ch);
+      buffer_PUTC(buffer_1,ch);
     }
   }
 }
