@@ -1,8 +1,6 @@
 #include "str.h"
 
-unsigned int str_chr(s,c)
-register char *s;
-int c;
+unsigned int str_chr(register char *s,int c)
 {
   register char ch;
   register char *t;
